Date: 01 4, 2002 11:23:24 AM

# uppercase

## Purpose

Pre action that succeeds if leaf token is all uppercase.

## Syntax

<fromRuleEltNumber,toRuleEltNumber>uppercase();

fromRuleEltNumber - type: int
toRuleEltNumber - type: int

## Returns

## Remarks

## Example

The action uppercase specifies that the first rule element (_xALPHA) must be a word in all capital letters in order to be reduced to the suggested node _noun.

@PRE
<1,1>uppercase();

@RULES
_noun <- _xALPHA@@

## See Also

lowercase, cap, PRE Actions